Learn R Programming

paisaje (version 0.2.0)

paisaje-package: paisaje: Spatial and Environmental Data Tools for Landscape Ecology

Description

Provides functions for landscape analysis and data retrieval. The package allows users to download environmental variables from global datasets (e.g., WorldClim, ESA WorldCover, Nighttime Lights), and to compute spatial and landscape metrics using a hexagonal grid system based on the H3 spatial index. It is useful for ecological modeling, biodiversity studies, and spatial data processing in landscape ecology. Fick and Hijmans (2017) tools:::Rd_expr_doi("10.1002/joc.5086"). Zanaga et al. (2022) tools:::Rd_expr_doi("10.5281/zenodo.7254221"). Uber Technologies Inc. (2022) "H3: Hexagonal hierarchical spatial index".

Arguments

Author

Maintainer: Manuel Spínola mspinola10@gmail.com (ORCID)

See Also